# Python API Reference

## Core Functions

```{eval-rst}
.. automodule:: noLZSS.core
   :members:
   :undoc-members:
   :show-inheritance:
```

## Utilities

```{eval-rst}
.. automodule:: noLZSS.utils
   :members:
   :undoc-members:
   :show-inheritance:
```

## Main Package

```{eval-rst}
.. automodule:: noLZSS
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: core, utils, genomics
```

## Exception Classes

### NoLZSSError
```{eval-rst}
.. autoclass:: noLZSS.NoLZSSError
   :members:
   :show-inheritance:
```

### InvalidInputError  
```{eval-rst}
.. autoclass:: noLZSS.InvalidInputError
   :members:
   :show-inheritance:
```